@@ -143,40 +143,136 @@ def get_data_col_names_from_root(data_root):
     ][-1]
 
 
-def parse_request_to_col_names(
+def find_cols_with_tide_tags(
+    data_columns: pd.Index | list[str], request: str
+) -> list[str]:
+    request_parts = request.split("__")
+
+    if not (1 <= len(request_parts) <= 4):
+        raise ValueError(
+            f"Request '{request}' is malformed. "
+            f"Use 'name__unit__bloc__sub_bloc' format or a "
+            f"combination of these tags."
+        )
+
+    full_tag_col_map = {
+        col_name_tag_enrichment(col, get_tags_max_level(data_columns)): col
+        for col in data_columns
+    }
+
+    def find_exact_match(search_str, target):
+        pattern = rf"(?:^|__)(?:{re.escape(search_str)})(?:$|__)"
+        match = re.search(pattern, target)
+        return match is not None
+
+    return [
+        full_tag_col_map[augmented_col]
+        for augmented_col in full_tag_col_map.keys()
+        if all(find_exact_match(part, augmented_col) for part in request_parts)
+    ]
+
+
+def find_cols_multiple_tag_groups(
+    data_columns: pd.Index | list[str], request: str
+) -> list[str]:
+    request_parts = request.split("|")
+    list_to_return = []
+    for req in request_parts:
+        list_to_return.extend(find_cols_with_tide_tags(data_columns, req))
+    return list_to_return
+
+
+def tide_request(
     data_columns: pd.Index | list[str], request: str | pd.Index | list[str] = None
 ) -> list[str]:
+    """
+    Select columns by matching structured TIDE-style tags.
+
+    Filters column names based on a TIDE-style structured tag syntax. Columns are
+    expected to use a naming convention with double underscores (`__`) separating
+    tags.
+
+    A column name can include up to four hierarchical parts:
+    'name__unit__bloc__sub_bloc' where each part is optional, but must be separated
+    with double underscores.
+
+    The `request` argument allows searching for columns matching one or more
+    of these parts using full or partial tag patterns. Multiple tag patterns
+    can be combined using the pipe `|` character to form OR conditions.
+
+    Parameters
+    ----------
+    data_columns : pandas.Index or list of str
+        A collection of column names to filter. Each column name should follow
+        the TIDE format (e.g., "sensor__°C__bloc1").
+
+    request : str or list of str or pandas.Index, optional
+        Tag(s) to match against the column names. Each tag string may be:
+
+        - A full structured tag (e.g., "name__°C__bloc2")
+        - A partial tag (e.g., "°C", "bloc1")
+        - A group of tags separated by "|" (e.g., "kWh|°C")
+
+        If None, all columns from `data_columns` are returned.
+
+    Returns
+    -------
+    list of str
+        The list of column names that match any of the provided tag queries.
+
+    Notes
+    -----
+    - Matching is done per tag part, not substrings. For instance, the query
+      "bloc1" will match "name__°C__bloc1" but not "bloc11".
+    - If multiple requests are given, columns are returned if they match
+      at least one of them (logical OR).
+    - Tags can include between 1 and 4 parts, split by `__`.
+
+    Examples
+    --------
+    >>> DF_COLUMNS = [
+    ...     "name_1__°C__bloc1",
+    ...     "name_1__°C__bloc2",
+    ...     "name_2",
+    ...     "name_2__DIMENSIONLESS__bloc2",
+    ...     "name_3__kWh/m²",
+    ...     "name_5__kWh",
+    ...     "name4__DIMENSIONLESS__bloc4",
+    ... ]
+
+    >>> tide_request(DF_COLUMNS)
+    ['name_1__°C__bloc1', 'name_1__°C__bloc2', 'name_2',
+     'name_2__DIMENSIONLESS__bloc2', 'name_3__kWh/m²',
+     'name_5__kWh', 'name4__DIMENSIONLESS__bloc4']
+
+    >>> tide_request(DF_COLUMNS, "°C")
+    ['name_1__°C__bloc1', 'name_1__°C__bloc2']
+
+    >>> tide_request(DF_COLUMNS, "kWh|°C")
+    ['name_5__kWh', 'name_1__°C__bloc1', 'name_1__°C__bloc2']
+
+    >>> # Columns are not selected twice
+    >>> tide_request(DF_COLUMNS, ["kWh|°C", "name_5__kWh"])
+    ['name_5__kWh', 'name_1__°C__bloc1', 'name_1__°C__bloc2']
+    """
+
     if request is None:
         return list(data_columns)
 
-    elif isinstance(request, pd.Index) or isinstance(request, list):
-        return [col for col in request if col in data_columns]
+    elif isinstance(request, str):
+        request = [request]
 
-    else:
-        request_parts = request.split("__")
+    if not (isinstance(request, pd.Index) or isinstance(request, list)):
+        raise ValueError(
+            "Invalid request. Was expected an instance of str, pd.Index or List[str]"
+            f"got {type(request)} instead"
+        )
 
-        if not (1 <= len(request_parts) <= 4):
-            raise ValueError(
-                f"Request '{request}' is malformed. "
-                f"Use 'name__unit__bloc__sub_bloc' format or a "
-                f"combination of these tags."
-            )
+    list_to_return = []
+    for req in request:
+        list_to_return.extend(find_cols_multiple_tag_groups(data_columns, req))
 
-        full_tag_col_map = {
-            col_name_tag_enrichment(col, get_tags_max_level(data_columns)): col
-            for col in data_columns
-        }
-
-        def find_exact_match(search_str, target):
-            pattern = rf"(?:^|__)(?:{re.escape(search_str)})(?:$|__)"
-            match = re.search(pattern, target)
-            return match is not None
-
-        return [
-            full_tag_col_map[augmented_col]
-            for augmented_col in full_tag_col_map.keys()
-            if all(find_exact_match(part, augmented_col) for part in request_parts)
-        ]
+    return list(dict.fromkeys(list_to_return))
 
 
 def data_columns_to_tree(columns: pd.Index | list[str]) -> T:
@@ -208,17 +304,22 @@ def data_columns_to_tree(columns: pd.Index | list[str]) -> T:
     return dict_to_tree(parsed_dict, sep="__")
 
 
+def check_datetime_index(idx: pd.DatetimeIndex):
+    if not isinstance(idx, pd.DatetimeIndex):
+        raise ValueError("Index is not a pandas DateTime index")
+
+    if idx.tz is None:
+        raise ValueError("Index must be tz_localized")
+
+
 def check_and_return_dt_index_df(X: pd.Series | pd.DataFrame) -> pd.DataFrame:
     if not (isinstance(X, pd.Series) or isinstance(X, pd.DataFrame)):
         raise ValueError(
             f"Invalid X data, was expected an instance of pandas Dataframe "
             f"or Pandas Series. Got {type(X)}"
         )
-    if not isinstance(X.index, pd.DatetimeIndex):
-        raise ValueError("X index is not a pandas DateTime index")
 
-    if X.index.tz is None:
-        raise ValueError("X index must be tz_localized")
+    check_datetime_index(X.index)
 
     return X.to_frame() if isinstance(X, pd.Series) else X
 
@@ -245,7 +346,7 @@ def _upper_bound(series, bound, bound_inclusive: bool, inner: bool):
     return op(series, bound)
 
 
-def get_series_bloc(
+def _get_series_bloc(
     date_series: pd.Series,
     is_null: bool = False,
     select_inner: bool = True,
@@ -314,16 +415,114 @@ def get_series_bloc(
     ]
 
 
+def get_blocks_lte_and_gte(
+    data: pd.Series | pd.DataFrame,
+    lte: str | dt.timedelta = None,
+    gte: str | dt.timedelta = None,
+    is_null: bool = False,
+    return_combination: bool = False,
+):
+    """
+    Get blocks of data ore gaps (nan) based on duration thresholds.
+
+    Returns them in a dictionary as list of DateTimeIndex. The keys values are
+    data columns (or name if data is a Series).
+
+
+    Parameters:
+    -----------
+    data : pd.Series or pd.DataFrame
+        The input data to be processed.
+    lte : str or datetime.timedelta, optional
+        The upper time threshold. Can be a string (e.g., '1h') or a timedelta object.
+    gte : str or datetime.timedelta, optional
+        The lower time threshold. Can be a string (e.g., '30min') or a timedelta object.
+    is_null : bool, default False
+        Whether to select blocks where the data is null.
+
+    Notes:
+    ------
+    - If both `lte` and `gte` are provided, and `lte` is smaller than `gte`, they
+    will be swapped. The function determines whether to select data within or outside
+    the boundaries based on the order of thresholds.
+    return_combination : bool, optional
+        If True (default), a combination column is created that checks for NaNs
+        across all columns in the DataFrame. Gaps in this combination column represent
+        rows where NaNs are present in any of the columns.
+    """
+
+    lower_th, upper_th = lte, gte
+    select_inner = False
+    if lower_th is not None and upper_th is not None:
+        if pd.to_timedelta(lower_th) > pd.to_timedelta(upper_th):
+            lower_th, upper_th = upper_th, lower_th
+            select_inner = True
+
+    return get_data_blocks(
+        data=data,
+        is_null=is_null,
+        lower_td_threshold=lower_th,
+        upper_td_threshold=upper_th,
+        select_inner=select_inner,
+        return_combination=return_combination,
+    )
+
+
+def get_blocks_mask_lte_and_gte(
+    data: pd.Series | pd.DataFrame,
+    lte: str | dt.timedelta = None,
+    gte: str | dt.timedelta = None,
+    is_null: bool = False,
+    return_combination: bool = False,
+) -> pd.DataFrame:
+    """
+    Creates a boolean mask DataFrame indicating the location of data blocks or gaps.
+
+    Parameters
+    ----------
+    data : pd.Series or pd.DataFrame
+        The input time series data with a DateTime index
+    lte : str or timedelta, optional
+        The minimum duration threshold
+    gte : str or timedelta, optional
+        The maximum duration threshold
+    is_null : bool, default False
+        Whether to find NaN blocks (True) or valid data blocks (False)
+    return_combination : bool, optional
+        If True (default), a combination column is created that checks for NaNs
+        across all columns in the DataFrame. Gaps in this combination column represent
+        rows where NaNs are present in any of the columns.
+
+    Returns
+    -------
+    pd.DataFrame
+        Boolean mask DataFrame with same index as input data and columns
+        corresponding to the input data columns. True values indicate
+        the presence of a block matching the criteria.
+    """
+    gaps_dict = get_blocks_lte_and_gte(data, lte, gte, is_null, return_combination)
+
+    mask_data = {}
+    for col, idx_list in gaps_dict.items():
+        if idx_list:
+            combined_idx = pd.concat([idx.to_series() for idx in idx_list]).index
+            mask_data[col] = data.index.isin(combined_idx)
+        else:
+            mask_data[col] = np.zeros(data.shape[0], dtype=bool)
+
+    return pd.DataFrame(mask_data, index=data.index)
+
+
 def get_data_blocks(
     data: pd.Series | pd.DataFrame,
     is_null: bool = False,
     cols: str | list[str] = None,
-    select_inner: bool = True,
     lower_td_threshold: str | dt.timedelta = None,
     upper_td_threshold: str | dt.timedelta = None,
+    select_inner: bool = True,
     lower_threshold_inclusive: bool = True,
     upper_threshold_inclusive: bool = True,
-    return_combination=True,
+    return_combination: bool = True,
 ):
     """
     Identifies groups of valid data if is_null = False, or groups of nan if
@@ -350,10 +549,9 @@ def get_data_blocks(
         Whether to return groups with valid data, or groups of Nan values
         (is_null = True)
     cols : str or list[str], optional
-        The columns in the DataFrame for which to detect gaps. If None (default), all
-        columns are considered.
-    select_inner : Bool, default True
-        Select the groups of data inside or outside the given boundaries
+        Columns to analyze. If None, uses all columns.
+    select_inner : bool, default True
+        If True, select groups within thresholds. If False, select groups outside thresholds.
     lower_td_threshold : str or timedelta, optional
         The minimum duration of a period for it to be considered valid.
         Can be passed as a string (e.g., '1d' for one day) or a `timedelta`.
@@ -381,17 +579,12 @@ def get_data_blocks(
         timestamps where the values in the corresponding column were NaN and
         exceeded the gap threshold.
     """
-
     data = check_and_return_dt_index_df(data)
+    cols = ensure_list(cols) or list(data.columns)
 
-    if isinstance(cols, str):
-        cols = [cols]
-    elif cols is None:
-        cols = list(data.columns)
-
-    idx_dict = {}
-    for col in cols:
-        idx_dict[col] = get_series_bloc(
+    # Process each column
+    idx_dict = {
+        col: _get_series_bloc(
             data[col],
             is_null,
             select_inner,
@@ -400,9 +593,11 @@ def get_data_blocks(
             lower_threshold_inclusive,
             upper_threshold_inclusive,
         )
+        for col in cols
+    }
 
     if return_combination:
-        idx_dict["combination"] = get_series_bloc(
+        idx_dict["combination"] = _get_series_bloc(
             ~data.isnull().any(axis=1),
             is_null,
             select_inner,
